==> aspose_words_cloud-20.6.0-py3-none-any.whl: asposewordscloud/models/hyperlink.py <==
# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="hyperlink.py">
#   Copyright (c) 2020 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import six


class Hyperlink(object):
    """Hyperlink element.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'link': 'WordsApiLink',
        'display_text': 'str',
        'value': 'str'
    }

    attribute_map = {
        'link': 'Link',
        'display_text': 'DisplayText',
        'value': 'Value'
    }

    def __init__(self, link=None, display_text=None, value=None):  # noqa: E501
        """Hyperlink - a model defined in Swagger"""  # noqa: E501

        self._link = None
        self._display_text = None
        self._value = None
        self.discriminator = None

        if link is not None:
            self.link = link
        if display_text is not None:
            self.display_text = display_text
        if value is not None:
            self.value = value

    @property
    def link(self):
        """Gets the link of this Hyperlink.  # noqa: E501

        Gets or sets link to the document.  # noqa: E501

        :return: The link of this Hyperlink.  # noqa: E501
        :rtype: WordsApiLink
        """
        return self._link

    @link.setter
    def link(self, link):
        """Sets the link of this Hyperlink.

        Gets or sets link to the document.  # noqa: E501

        :param link: The link of this Hyperlink.  # noqa: E501
        :type: WordsApiLink
        """
        self._link = link

    @property
    def display_text(self):
        """Gets the display_text of this Hyperlink.  # noqa: E501

        Gets or sets hypelink's display text.  # noqa: E501

        :return: The display_text of this Hyperlink.  # noqa: E501
        :rtype: str
        """
        return self._display_text

    @display_text.setter
    def display_text(self, display_text):
        """Sets the display_text of this Hyperlink.

        Gets or sets hypelink's display text.  # noqa: E501

        :param display_text: The display_text of this Hyperlink.  # noqa: E501
        :type: str
        """
        self._display_text = display_text

    @property
    def value(self):
        """Gets the value of this Hyperlink.  # noqa: E501

        Gets or sets value.  # noqa: E501

        :return: The value of this Hyperlink.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this Hyperlink.

        Gets or sets value.  # noqa: E501

        :param value: The value of this Hyperlink.  # noqa: E501
        :type: str
        """
        self._value = value


    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Hyperlink):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> aspose_words_cloud-21.2.0-py3-none-any.whl: asposewordscloud/models/hyperlink.py <==
# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="hyperlink.py">
#   Copyright (c) 2021 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import datetime
import six
import json


class Hyperlink(object):
    """Hyperlink element.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'link': 'WordsApiLink',
        'display_text': 'str',
        'value': 'str'
    }

    attribute_map = {
        'link': 'Link',
        'display_text': 'DisplayText',
        'value': 'Value'
    }

    def __init__(self, link=None, display_text=None, value=None):  # noqa: E501
        """Hyperlink - a model defined in Swagger"""  # noqa: E501

        self._link = None
        self._display_text = None
        self._value = None
        self.discriminator = None

        if link is not None:
            self.link = link
        if display_text is not None:
            self.display_text = display_text
        if value is not None:
            self.value = value

    @property
    def link(self):
        """Gets the link of this Hyperlink.  # noqa: E501

        Gets or sets the link to the document.  # noqa: E501

        :return: The link of this Hyperlink.  # noqa: E501
        :rtype: WordsApiLink
        """
        return self._link

    @link.setter
    def link(self, link):
        """Sets the link of this Hyperlink.

        Gets or sets the link to the document.  # noqa: E501

        :param link: The link of this Hyperlink.  # noqa: E501
        :type: WordsApiLink
        """
        self._link = link

    @property
    def display_text(self):
        """Gets the display_text of this Hyperlink.  # noqa: E501

        Gets or sets the hypelink's display text.  # noqa: E501

        :return: The display_text of this Hyperlink.  # noqa: E501
        :rtype: str
        """
        return self._display_text

    @display_text.setter
    def display_text(self, display_text):
        """Sets the display_text of this Hyperlink.

        Gets or sets the hypelink's display text.  # noqa: E501

        :param display_text: The display_text of this Hyperlink.  # noqa: E501
        :type: str
        """
        self._display_text = display_text

    @property
    def value(self):
        """Gets the value of this Hyperlink.  # noqa: E501

        Gets or sets the value.  # noqa: E501

        :return: The value of this Hyperlink.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this Hyperlink.

        Gets or sets the value.  # noqa: E501

        :param value: The value of this Hyperlink.  # noqa: E501
        :type: str
        """
        self._value = value


    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Hyperlink):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
